**Flask-SSO** is an extension that eases Shibboleth authentication.

.. image:: https://travis-ci.org/inveniosoftware/flask-sso.png?branch=master
    :target: https://travis-ci.org/inveniosoftware/flask-sso
.. image:: https://coveralls.io/repos/inveniosoftware/flask-sso/badge.png?branch=master
    :target: https://coveralls.io/r/inveniosoftware/flask-sso


User's Guide
============

This part of the documentation will show you how to get started in using
Flask-SSO with Flask.

.. toctree::
   :maxdepth: 2

   installation
   quickstart
   userguide


API Reference
============

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


Additional Notes
================

Notes on how to contribute, legal information and changelog are here for the interested.

.. toctree::
   :maxdepth: 2

   contributing
   changelog
   license
